# file RODBC/R/RODBC.R
# copyright (C) 1999-2013  M. Lapsley and B. D. Ripley
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 or 3 of the License
#  (at your option).
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  A copy of the GNU General Public License is available at
#  http://www.r-project.org/Licenses/

odbcValidChannel = function(channel)
{
  return(
    inherits(channel, "RODBC") && 
    is.integer(channel) &&
    .Call("RODBCcheckchannel", channel, attr(channel, "id")) > 0
  )
}